@@ -114,7 +114,7 @@ class LocalCacheProvider(singletonmixin.Singleton):
 localCache = LocalCacheProvider.getInstance()
 
 def attachSettings(settingsLocals, services=(
-                    'queue', 'mail', 'logging', 'storage'),
+                    'queue', 'mail', 'logging', 'browser', 'storage'),
                    serviceSettings=None,
                    loggingFile=None, loggingLevel=None,
                    cache=False, cacheDir=None):
@@ -208,9 +208,12 @@ def attachSettings(settingsLocals, services=(
                                          if preferred else None,
                                context=settingsLocals,
                                config=config)
-
-        servicePackage.attachSettings(settingsLocals, backends, preferred,
-                                      config)
+        try:
+            servicePackage.attachSettings(settingsLocals, backends, preferred,
+                                          config)
+        except ImportError as ex:
+            logger.warn('%s can not be imported: %s' % (service, str(ex)))
+            continue
 
 import pkgutil
 
